package ch.hslu.appe.inventory.webservice;

import java.util.ArrayList;
import java.util.List;

import javax.jws.HandlerChain;
import javax.jws.WebService;

import ch.hslu.appe.inventory.logic.InventorySystem;
import ch.hslu.appe.inventory.logic.InventorySystemImpl;
import ch.hslu.appe.inventory.model.Product;
import ch.hslu.appe.inventory.webservice.dto.ProductDto;

/**
 * Inventory / Stock System Webservice Implementation.
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 */
@WebService(endpointInterface = "ch.hslu.appe.inventory.webservice.InventoryService")
@HandlerChain(file = "./handler/handlers.xml")
public final class InventoryServiceImpl implements InventoryService {

    private static final InventorySystem INVENTORY_SYSTEM = new InventorySystemImpl();

    @Override
    public List<ProductDto> getActiveProducts() {

        final List<ProductDto> products = new ArrayList<ProductDto>();

        for (Product product : INVENTORY_SYSTEM.getActiveProducts()) {
            products.add(ProductDto.fromProduct(product));
        }

        return products;
    }

    @Override
    public ProductDto getProduct(final int productNumber) {
        return ProductDto.fromProduct(INVENTORY_SYSTEM.getProduct(productNumber));
    }

    @Override
    public List<ProductDto> getProducts() {

        final List<ProductDto> products = new ArrayList<ProductDto>();

        for (Product product : INVENTORY_SYSTEM.getProducts()) {
            products.add(ProductDto.fromProduct(product));
        }

        return products;
    }

    @Override
    public boolean productActive(final int productNumber) {
        return INVENTORY_SYSTEM.productActive(productNumber);
    }

    @Override
    public boolean productExists(final int productNumber) {
        return INVENTORY_SYSTEM.productExists(productNumber);
    }
}
