package ch.hslu.appe.inventory.webservice.dto;

import ch.hslu.appe.inventory.model.Product;

/**
 * DTO for Product, Contains all information about one product.
 * @author Felix Rohrer <felix.rohrer@stud.hslu.ch>
 */
public final class ProductDto {

    /**
     * Constructor to create a ProductDto based on a Product.
     * @param product product to be filled in productDto
     * @return Product DTO
     */
    public static ProductDto fromProduct(final Product product) {
        if (product == null) {
            return null;
        }

        final ProductDto productDto = new ProductDto();
        productDto.setActive(product.isActive());
        productDto.setAmount(product.getAmount());
        productDto.setAmountmin(product.getAmountmin());
        productDto.setId(product.getId());
        productDto.setNumber(product.getNumber());
        productDto.setPrice(product.getPrice());
        productDto.setProductname(product.getProductname());

        return productDto;
    }
    private boolean active;
    private int amount;
    private int amountmin;
    private int id;
    private int number;
    private float price;

    private String productname;

    /**
     * gets the amount of pieces we have in our stock.
     * @return the amount in stock
     */
    public int getAmount() {
        return amount;
    }


    /**
     * get the minimum pieces we need to have in our stock.
     * @return the minimum amount in stock
     */
    public int getAmountmin() {
        return amountmin;
    }

    /**
     * Gets the unique product id, generated by the database.
     * @return the id
     */
    public int getId() {
        return id;
    }

    /**
     * gets the unique order id, generated by the database.
     * @return the order number
     */
    public int getNumber() {
        return number;
    }

    /**
     * gets the price of the product.
     * @return the price
     */
    public float getPrice() {
        return price;
    }

    /**
     * gets the product name.
     * @return the product name
     */
    public String getProductname() {
        return productname;
    }

    /**
     * gets if the product is active (true) or not (false).
     * @return the active state
     */
    public boolean isActive() {
        return active;
    }

    /**
     * sets the state, active (true) or inactive (false).
     * @param active the active to set
     */
    public void setActive(final boolean active) {
        this.active = active;
    }

    /**
     * sets the amount of pieces we have in our stock.
     * @param amount the amount to set
     */
    public void setAmount(final int amount) {
        this.amount = amount;
    }

    /**
     * sets the minimum of pieces we need to have in our stock.
     * @param amountmin minimum amount in stock to set
     */
    public void setAmountmin(final int amountmin) {
        this.amountmin = amountmin;
    }

    /**
     * sets the id.
     * @param id to be set
     */
    public void setId(final int id) {
        this.id = id;
    }

    /**
     * sets the product number.
     * @param number the product number to set
     */
    public void setNumber(final int number) {
        this.number = number;
    }

    /**
     * sets a new price for the product.
     * @param price the price to set
     */
    public void setPrice(final float price) {
        this.price = price;
    }

    /**
     * sets the product name.
     * @param name the name to set
     */
    public void setProductname(final String name) {
        this.productname = name;
    }
}
