package ch.hslu.appe.order.webservice.dto;

import java.util.ArrayList;
import java.util.Date;

import javax.xml.bind.annotation.XmlElement;

import ch.hslu.appe.order.model.BillState;
import ch.hslu.appe.order.model.DeliverState;
import ch.hslu.appe.order.model.Order;
import ch.hslu.appe.order.model.OrderPosition;
import ch.hslu.appe.order.model.OrderState;
import ch.hslu.appe.usermanagement.exception.IllegalNameException;
import ch.hslu.appe.usermanagement.webservice.dto.AddressDto;
import ch.hslu.appe.usermanagement.webservice.dto.UserDto;

/**
 * Order DTO.
 */
public final class OrderDto {

    /**
     * OrderDTO Constructor to create the DTO from an Order.
     * @param order order
     * @return OrderDTO
     */
    public static OrderDto fromOrder(final Order order) {

        if (order == null) {
            return null;
        }

        final OrderDto orderDto = new OrderDto();

        if (order.getCustomer() != null) {
            orderDto.setCustomer(UserDto.fromUser(order.getCustomer()));
        }

        if (order.getSales() != null) {
            orderDto.setSales(UserDto.fromUser(order.getSales()));
        }

        if (order.getDeliverAddress() != null) {
            orderDto.setDeliverAddress(AddressDto.fromAddress(order.getDeliverAddress()));
        }

        orderDto.setDeliverCost(order.getDeliverCost());
        orderDto.setDeliverDate(order.getDeliverDate());
        orderDto.setDeliverState(order.getDeliverState().ordinal());
        orderDto.setId(order.getId());
        orderDto.setNumber(order.getNumber());
        orderDto.setOrderDate(order.getOrderDate());
        orderDto.setOrderState(order.getOrderState().ordinal());
        orderDto.setPayState(order.getPayState().ordinal());

        final ArrayList<OrderPositionDto> positions = new ArrayList<OrderPositionDto>();
        if (order.getOrderPositions() != null) {

            for (OrderPosition position : order.getOrderPositions()) {
                positions.add(OrderPositionDto.fromOrderPosition(position));
            }
        }
        orderDto.setOrderPositions(positions);

        return orderDto;
    }

    private UserDto customer;
    private AddressDto deliverAddress;
    private float deliverCost;
    private Date deliverDate;
    private int deliverState;
    private int id;
    private int number;
    private Date orderDate;
    private ArrayList<OrderPositionDto> orderPositions;
    private int orderState;
    private int payState;
    private UserDto sales;

    /**
     * Returns the Customer.
     * @return customer
     */
    @XmlElement(required = true)
    public UserDto getCustomer() {
        return customer;
    }

    /**
     * Returns the DeliverAddress.
     * @return deliverAddress
     */
    @XmlElement(required = true)
    public AddressDto getDeliverAddress() {
        return deliverAddress;
    }

    /**
     * Returns the DeliverCost.
     * @return deliverCost
     */
    @XmlElement(required = true)
    public float getDeliverCost() {
        return deliverCost;
    }

    /**
     * Returns the DeliverDate.
     * @return deliverDate
     */
    @XmlElement(required = true)
    public Date getDeliverDate() {
        return deliverDate;
    }

    /**
     * Returns the DeliverState.
     * @return deliverState
     */
    @XmlElement(required = true)
    public int getDeliverState() {
        return deliverState;
    }

    /**
     * Returns the ID.
     * @return id
     */
    @XmlElement(required = true)
    public int getId() {
        return id;
    }

    /**
     * Returns the OrderNumber.
     * @return orderNumber
     */
    @XmlElement(required = true)
    public int getNumber() {
        return number;
    }

    /**
     * Returns the OrderDate.
     * @return orderDate
     */
    @XmlElement(required = true)
    public Date getOrderDate() {
        return orderDate;
    }

    /**
     * Returns all OrderPositions.
     * @return list with all OrderPositions
     */
    @XmlElement(required = true)
    public ArrayList<OrderPositionDto> getOrderPositions() {
        return orderPositions;
    }

    /**
     * Returns the OrderSate.
     * @return orderState
     */
    @XmlElement(required = true)
    public int getOrderState() {
        return orderState;
    }

    /**
     * Returns the PayState.
     * @return payState
     */
    @XmlElement(required = true)
    public int getPayState() {
        return payState;
    }

    /**
     * Returns the SalesUser.
     * @return salesUser
     */
    @XmlElement(required = true)
    public UserDto getSales() {
        return sales;
    }

    /**
     * Sets the Customer.
     * @param customer to be set
     */
    public void setCustomer(final UserDto customer) {
        this.customer = customer;
    }

    /**
     * Sets the DeliverAddress.
     * @param deliverAddress to be set
     */
    public void setDeliverAddress(final AddressDto deliverAddress) {
        this.deliverAddress = deliverAddress;
    }

    /**
     * Sets the DeliverCost.
     * @param deliverCost to be set
     */
    public void setDeliverCost(final float deliverCost) {
        this.deliverCost = deliverCost;
    }

    /**
     * Sets the DeliverDate.
     * @param deliverDate to be set
     */
    public void setDeliverDate(final Date deliverDate) {
        this.deliverDate = deliverDate;
    }

    /**
     * Sets the DeliverState.
     * @param deliverState to be set
     */
    public void setDeliverState(final int deliverState) {
        this.deliverState = deliverState;
    }

    /**
     * Sets the ID.
     * @param id to be set
     */
    public void setId(final int id) {
        this.id = id;
    }

    /**
     * Sets the OrderNumber.
     * @param number to be set
     */
    public void setNumber(final int number) {
        this.number = number;
    }

    /**
     * Sets the OrderDate.
     * @param orderDate to be set
     */
    public void setOrderDate(final Date orderDate) {
        this.orderDate = orderDate;
    }

    /**
     * Sets all OrderPositions.
     * @param orderPositions to be set
     */
    public void setOrderPositions(final ArrayList<OrderPositionDto> orderPositions) {
        this.orderPositions = orderPositions;
    }

    /**
     * Sets the OrderState.
     * @param orderState to be set
     */
    public void setOrderState(final int orderState) {
        this.orderState = orderState;
    }

    /**
     * Sets the PayState.
     * @param payState to be set
     */
    public void setPayState(final int payState) {
        this.payState = payState;
    }

    /**
     * Sets the SalesUser.
     * @param sales to be set
     */
    public void setSales(final UserDto sales) {
        this.sales = sales;
    }

    /**
     * Convert the OrderDTO to a Order.
     * @return order
     * @throws IllegalNameException IllegalNameException
     */
    public Order toOrder() throws IllegalNameException {

        final Order order = new Order();

        if (getCustomer() != null) {
            order.setCustomer(getCustomer().toUser());
        }

        if (getSales() != null) {
            order.setSales(getSales().toUser());
        }

        if (getDeliverAddress() != null) {
            order.setDeliverAddress(getDeliverAddress().toAddress());
        }

        order.setDeliverCost(getDeliverCost());
        order.setDeliverDate(getDeliverDate());
        order.setDeliverState(DeliverState.values()[getDeliverState()]);
        order.setId(getId());
        order.setNumber(getNumber());
        order.setOrderDate(getOrderDate());
        order.setOrderState(OrderState.values()[getOrderState()]);
        order.setPayState(BillState.values()[getPayState()]);

        final ArrayList<OrderPosition> positions = new ArrayList<OrderPosition>();
        if (order.getOrderPositions() != null) {

            for (OrderPositionDto position : getOrderPositions()) {

                final OrderPosition orderPosition = position.toOrderPosition();
                orderPosition.setOrder(order);

                positions.add(orderPosition);
            }
        }
        order.setOrderPositions(positions);

        return order;
    }

}
