package ch.hslu.appe.order.webservice.dto;

import javax.xml.bind.annotation.XmlElement;

import ch.hslu.appe.order.model.OrderPosition;

/**
 * OrderPosition DTO.
 */
public final class OrderPositionDto {

    /**
     * Constructor to convert from OrderPosition to DTO.
     * @param orderPosition OrderPosition
     * @return OrderPosition DTO
     */
    public static OrderPositionDto fromOrderPosition(final OrderPosition orderPosition) {

        if (orderPosition == null) {
            return null;
        }

        final OrderPositionDto orderPositionDto = new OrderPositionDto();

        if (orderPosition.getProduct() != null) {
            orderPositionDto.setProductNumber(orderPosition.getProduct().getNumber());
        }

        orderPositionDto.setAmount(orderPosition.getAmount());
        orderPositionDto.setId(orderPosition.getId());
        orderPositionDto.setPosition(orderPosition.getPosition());
        orderPositionDto.setPrice(orderPosition.getPrice());

        return null;
    }

    private int amount;
    private int id;
    private boolean outstanding;
    private int position;
    private float price;
    private int productNumber;

    /**
     * Returns the amount.
     * @return amount
     */
    @XmlElement(required = true)
    public int getAmount() {
        return amount;
    }

    /**
     * Returns the ID.
     * @return id
     */
    @XmlElement(required = true)
    public int getId() {
        return id;
    }

    /**
     * Returns the Position.
     * @return position
     */
    @XmlElement(required = true)
    public int getPosition() {
        return position;
    }

    /**
     * Returns the Price.
     * @return price
     */
    @XmlElement(required = true)
    public float getPrice() {
        return price;
    }

    /**
     * Returns the ProductNumber.
     * @return productNumber
     */
    @XmlElement(required = true)
    public int getProductNumber() {
        return productNumber;
    }

    /**
     * Return if the Product is outstanding (true).
     * @return true if outstanding otherwise false
     */
    @XmlElement(required = true)
    public boolean isOutstanding() {
        return outstanding;
    }

    /**
     * Sets the amount.
     * @param amount to be set
     */
    public void setAmount(final int amount) {
        this.amount = amount;
    }

    /**
     * Sets the Id.
     * @param id to be set
     */
    public void setId(final int id) {
        this.id = id;
    }

    /**
     * Sets if the Product is outstanding (true).
     * @param outstanding to be set
     */
    public void setOutstanding(final boolean outstanding) {
        this.outstanding = outstanding;
    }


    /**
     * Sets the Position.
     * @param position to be set
     */
    public void setPosition(final int position) {
        this.position = position;
    }

    /**
     * Sets the price.
     * @param price to be set
     */
    public void setPrice(final float price) {
        this.price = price;
    }

    /**
     * Sets the ProductNumber.
     * @param productNumber to be set
     */
    public void setProductNumber(final int productNumber) {
        this.productNumber = productNumber;
    }

    /**
     * Add a new OrderPosition.
     * @return orderPosition
     */
    public OrderPosition toOrderPosition() {
        final OrderPosition orderPosition = new OrderPosition();

        // Cant get the product here, you have to do it outside
        orderPosition.setAmount(getAmount());
        orderPosition.setId(getId());
        orderPosition.setPosition(getPosition());
        orderPosition.setPrice(getPrice());

        return orderPosition;
    }
}
