package ch.hslu.appe.usermanagement.logic.session;

import java.util.Date;

import ch.hslu.appe.usermanagement.model.User;

/**
 * Session.
 */
public final class Session {

    private final String key;
    private final User user;
    private Date validUntil;

    /**
     * Constructor.
     * @param user User
     * @param key SessionKey
     * @param validUntil Session timeOut
     */
    public Session(final User user, final String key, final Date validUntil) {

        this.user = user;
        this.key = key;
        this.validUntil = validUntil;
    }

    /**
     * Extends the validity of this session by a specific amount of minutes.
     * @param minutes Amount of minutes to extend this session
     */
    public void extend(final int minutes) {

        final long time = validUntil.getTime();

        // Add the minutes
        validUntil = new Date(time + (minutes * 60000L));
    }

    /**
     * Gets the key.
     * @return Returns the key
     */
    public String getKey() {
        return key;
    }

    /**
     * Gets the user.
     * @return Returns the user
     */
    public User getUser() {
        return user;
    }

    /**
     * Gets the date, until this session will be valid.
     * @return Returns the validate till date
     */
    public Date getValidUntil() {
        return validUntil;
    }

}
