package ch.hslu.appe.usermanagement.webservice.dto;

import javax.xml.bind.annotation.XmlElement;

import ch.hslu.appe.usermanagement.model.Address;
import ch.hslu.appe.usermanagement.model.AddressType;
import ch.hslu.appe.usermanagement.model.Place;

/**
 * Address DTO.
 */
public final class AddressDto {

    /**
     * Constructor to create a Address DTO from a Address Object.
     * @param address address
     * @return addressDTO
     */
    public static AddressDto fromAddress(final Address address) {

        if (address == null) {
            return null;
        }

        final AddressDto addressDto = new AddressDto();

        addressDto.setId(address.getId());
        addressDto.setStreet(address.getStreet());
        addressDto.setType(address.getType().ordinal());

        if (address.getPlace() != null) {
            addressDto.setPlaceId(address.getPlace().getId());
            addressDto.setPlace(address.getPlace().getName());
            addressDto.setZipCode(address.getPlace().getZipCode());
        }

        return addressDto;
    }

    private int id;
    private String place;
    private int placeId;
    private String street;
    private int type;
    private int zipCode;

    /**
     * Returns the ID.
     * @return id
     */
    @XmlElement(required = true)
    public int getId() {
        return id;
    }

    /**
     * Returns the Place.
     * @return place
     */
    @XmlElement(required = true)
    public String getPlace() {
        return place;
    }

    /**
     * Returns the PlaceId.
     * @return placeId
     */
    @XmlElement(required = true)
    public int getPlaceId() {
        return placeId;
    }

    /**
     * Returns the Street.
     * @return street
     */
    @XmlElement(required = true)
    public String getStreet() {
        return street;
    }

    /**
     * Returns the Type.
     * @return type
     */
    @XmlElement(required = true)
    public int getType() {
        return type;
    }

    /**
     * Returns the ZipCode.
     * @return zipCode
     */
    @XmlElement(required = true)
    public int getZipCode() {
        return zipCode;
    }

    /**
     * Sets the Id.
     * @param id to be set
     */
    public void setId(final int id) {
        this.id = id;
    }

    /**
     * Sets the Place.
     * @param place to be set
     */
    public void setPlace(final String place) {
        this.place = place;
    }

    /**
     * Sets the PlaceId.
     * @param placeId to be set
     */
    public void setPlaceId(final int placeId) {
        this.placeId = placeId;
    }

    /**
     * Sets the Street.
     * @param street to be set
     */
    public void setStreet(final String street) {
        this.street = street;
    }

    /**
     * Sets the Type.
     * @param type to be set
     */
    public void setType(final int type) {
        this.type = type;
    }

    /**
     * Sets the ZipCode.
     * @param zipCode to be set
     */
    public void setZipCode(final int zipCode) {
        this.zipCode = zipCode;
    }

    /**
     * Convert the DTO to a Address-Object.
     * @return addressObject
     */
    public Address toAddress() {
        final Address address = new Address();
        final Place newPlace = new Place();
        newPlace.setId(getPlaceId());
        newPlace.setZipCode(getZipCode());

        address.setId(getId());
        address.setStreet(street);
        address.setPlace(newPlace);
        address.setType(AddressType.values()[type]);

        return address;
    }
}
